@@ -170,8 +170,11 @@ class ExprList(ExprPrint, list, ExprContainer, ExprMisc):
     # in preference to list's one.  Alternatively, add explicit
     # _repr_pretty_ method here.
     
-    def __init__(self, iterable=[], evalf=False):
+    def __init__(self, iterable=None, evalf=False):
 
+        if iterable is None:
+            iterable = []
+        
         eiterable = []
         for item in iterable:
             if evalf:
@@ -455,7 +458,7 @@ class Expr(ExprPrint, ExprMisc):
 
 
         # If it is not callable, directly wrap it.
-        if not hasattr(a, '__call__'):
+        if not callable(a):
             if not isinstance(a, sym.Expr):
                 return a
             ret = a
@@ -608,7 +611,8 @@ class Expr(ExprPrint, ExprMisc):
         if cls in (Expr, cExpr):
             return xcls, cls(self), x, assumptions
 
-        if cls in (Impedance, Admittance) and isinstance(x, omegaExpr):
+        if (cls in (Impedance, Admittance, Resistance, Reactance, Conductance, Susceptance) and
+            isinstance(x, omegaExpr)):
             return cls, self, cls(x), assumptions        
 
         raise ValueError('Cannot combine %s(%s) with %s(%s) for %s' %
@@ -972,8 +976,8 @@ class Expr(ExprPrint, ExprMisc):
         """Return magnitude"""
 
         if self.is_real:
-            dst = self.copy()
-            dst.part = 'real'            
+            dst = expr(abs(self.expr))
+            dst.part = 'magnitude'            
             return dst
 
         R = self.rationalize_denominator()
@@ -1016,7 +1020,10 @@ class Expr(ExprPrint, ExprMisc):
         N = R.N
 
         if N.imag == 0:
-            dst = N.imag
+            if N.real >= 0:
+                dst = expr(0)
+            else:
+                dst = expr(sym.pi)
         else:
             if N.real != 0:
                 G = gcd(N.real, N.imag)
@@ -1567,6 +1574,8 @@ class Expr(ExprPrint, ExprMisc):
         See also general, partfrac, standard, timeconst, and ZPK
 
         """
+        if not self.expr.has(self.var):
+            return self
         if self._ratfun is None:
             return self.copy()
         return self.__class__(self._ratfun.canonical(factor_const),
@@ -2124,6 +2133,10 @@ from .sexpr import Hs, Is, Vs, Ys, Zs, sExpr, sexpr
 from .texpr import tExpr, texpr
 from .impedance import Impedance
 from .admittance import Admittance
+from .resistance import *
+from .reactance import *
+from .conductance import *
+from .susceptance import *
 from .voltage import Voltage
 from .current import Current
 from .omegaexpr import Homega, Iomega, Vomega, Yomega, Zomega, omegaExpr, omegaexpr
