@@ -7,7 +7,7 @@ Copyright 2014--2019 Michael Hayes, UCECE
 from __future__ import division
 from .phasor import Iphasor, Vphasor
 from .vector import Vector
-from .matrix import Matrix
+from .matrix import Matrix, matrix_inverse
 from .sym import symsimplify
 from .expr import ExprDict, expr
 from .voltage import Vtype
@@ -143,8 +143,7 @@ class MNAMixin(object):
             # but hangs on some matrices with sympy-1.6.1
             # Comparative times for the testsuites are:
             # GE 66, ADJ 73, LU 76. 
-            Ainv = self._A.inv()           
-            #Ainv = self._A.inv(method='ADJ')
+            Ainv = matrix_inverse(self._A)
         except ValueError:
             comment = ''
             if self.kind == 'dc':
