@@ -14,7 +14,7 @@ from .symbols import j, omega, jomega, s, t
 from .functions import sqrt
 from .sym import capitalize_name, omegasym
 from .grammar import delimiters
-from .immitance import ImmitanceMixin
+from .immittancemixin import ImmittanceMixin
 from .current import Current
 from .opts import Opts
 import lcapy
@@ -30,7 +30,7 @@ cptaliases = {'E': 'VCVS', 'F': 'CCCS',
               'k': 'Spring'}
 
 
-class Cpt(ImmitanceMixin):
+class Cpt(ImmittanceMixin):
 
     dependent_source = False
     independent_source = False    
@@ -83,7 +83,7 @@ class Cpt(ImmitanceMixin):
             self.cpt = lcapy.oneport.Dummy()
             return
 
-        if ((args is () and not self.type in ('W', 'O', 'P'))
+        if ((args == () and not self.type in ('W', 'O', 'P'))
             or (self.type in ('F', 'H', 'CCCS', 'CCVS') and len(args) == 1)
             or (self.type == 'K' and len(args) == 2)):
             # Default value is the component name
