@@ -60,8 +60,8 @@ class EquipotentialNodes(dict):
 
         # Iterate over all pairs.
         for i in range(len(nodes)):
-            for j in range(i + 1, len(nodes)):
-                self.add_wire(nodes[i], nodes[j])
+            for m in range(i + 1, len(nodes)):
+                self.add_wire(nodes[i], nodes[m])
             
 
 class NetlistNamespace(object):
@@ -467,10 +467,13 @@ class NetlistMixin(object):
             new.add(net)
         return new                
     
-    def augment_node_map(self, node_map={}):
+    def augment_node_map(self, node_map=None):
 
         """Create a mapping dict for all nodes."""
 
+        if node_map is None:
+            node_map = {}
+        
         # It would be desirable to renumber the nodes say from left to
         # right and top to bottom.  The schematic drawing algorithms
         # could help with this since they figure out the node
@@ -521,10 +524,13 @@ class NetlistMixin(object):
 
         return node_map
     
-    def renumber(self, node_map={}):
+    def renumber(self, node_map=None):
         """Renumber nodes using specified node_map.  If node_map not specified
         then a mapping is created."""
 
+        if node_map is None:
+            node_map = {}
+        
         if len(node_map) != len(self.nodes):
             node_map = self.augment_node_map(node_map)
 
@@ -1887,7 +1893,7 @@ class SubNetlist(NetlistMixin, MNAMixin):
         obj._analysis = obj.analyse()
         return obj
 
-    def __init__(cls, netlist, kind):
+    def __init__(self, netlist, kind):
         """ kind can be 't', 'dc', 'ac', 's', 'time', 'ivp', 'n*', omega, 
         or an integer"""
         
