@@ -11,7 +11,6 @@ from .expr import Expr, ExprDict, expr
 from .sym import tsym, omega0sym, symbols_find, is_sympy, symsymbol
 from .acdc import is_ac
 from .printing import pprint, pretty, latex
-import six
 
 __all__ = ('Super', 'Voltage', 'Current')
 
@@ -64,13 +63,26 @@ class Super(ExprDict):
     def _representation(self):
         if not any(self):
             return 0
-        if False:
-            return self
-        # It is probably less confusing for a user to display
+
+        decomp = self.decompose()
+        
+        # If have a single element, show value.
+        if len(decomp) == 1:
+            key = list(decomp)[0]
+            if key in ('dc', 't'):
+                return decomp[key]
+            if key == 's':
+                if decomp[key].has(s):
+                    return decomp[key]
+                # Have something like s * 0 + 1 so don't display as 1
+                # since not a dc value.
+        
+        # Have a superposition.
+        # It is probably less confusing to a user to display
         # using a decomposition in the transform domains.
         # We could present the result in the time-domain but this
         # hides the underlying way the signal is analysed.
-        return self.decompose()
+        return decomp
 
     def latex(self, **kwargs):
         """Latex"""
@@ -100,15 +112,23 @@ class Super(ExprDict):
         # instead of 'omega'.
         if isinstance(key, Expr):
             key = key.expr
-        return super(Super, self).__getitem__(key)
+        if key in self:
+            return super(Super, self).__getitem__(key)
+        decomp = self.decompose()
+        if key == 0 and 'dc' in decomp:
+            key = 'dc'
+        if key not in decomp:
+            raise IndexError('Unknown signal component %s' % key)
+        
+        return decomp.__getitem__(key)        
 
     @property
     def symbols(self):
         """Return dictionary of symbols in the expression keyed by name."""
 
         syms = {}
-        for expr in self.values():
-            syms.update(expr.symbols)
+        for expr1 in self.values():
+            syms.update(expr1.symbols)
         return syms
 
     def ac_keys(self):
@@ -135,8 +155,8 @@ class Super(ExprDict):
          V.has(t)
 
         """        
-        for key,expr  in self.items():
-            if expr.has(subexpr):
+        for key, expr1 in self.items():
+            if expr1.has(subexpr):
                 return True
         return False
 
@@ -188,6 +208,12 @@ class Super(ExprDict):
         """True if only has AC components."""                        
         return self.has_ac and self.ac_keys() == list(self.keys())
 
+    @property
+    def is_phasor(self):
+        """True if has single AC component."""
+
+        return self.ac and len(list(self.keys())) == 1
+    
     @property
     def is_noisy(self):
         """True if only has noise components."""                                
@@ -517,7 +543,7 @@ class Super(ExprDict):
                 self.add(value)
             return
 
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             return self._parse(value)
 
         if isinstance(value, noiseExpr):
@@ -560,11 +586,68 @@ class Super(ExprDict):
         else:
             self[kind] += value
 
+    @property
+    def magnitude(self):
+        """Return the magnitude if phasor."""        
+        
+        phasor = self.phasor
+        return phasor.magnitude
+
+    @property
+    def abs(self):
+        """Return the magnitude if phasor."""                
+        return self.magnitude
+
+    @property
+    def omega(self):
+        """Return angular frequency if phasor."""                
+        return self.omega
+    
+    @property
+    def phase(self):
+        """Return the phase if phasor."""        
+        
+        phasor = self.phasor
+        return phasor.phase    
+            
     @property
     def dc(self):
         """Return the DC component."""        
         return self.select('dc')
 
+    @property
+    def _single(self):
+        """Extract single expression; raise error if a superposition."""
+
+        decomp = self.decompose()
+        
+        if len(decomp) > 1:
+            raise ValueError("""
+This is superposition of multiple signals.  You will need to extract a single
+expression.""")
+    
+        key = list(decomp)[0]
+        return decomp[key]
+    
+    @property
+    def phasor(self):
+        """Return phasor if have a single AC component otherwise raise error."""
+
+        decomp = self.decompose()
+        
+        if not decomp.has_ac:
+            raise ValueError('Not a phasor')
+
+        if len(decomp) > 1:
+            foo = ', '.join(['expr[%s]' % key for key in self.ac_keys()])
+            
+            raise ValueError("""
+This is superposition of phasors.  You will need to extract a single
+phasor, for example, using: %s""" % foo)
+        
+        expr1 = decomp._single
+        return expr1
+    
     @property
     def ac(self):
         """Return the AC components."""                
