@@ -56,6 +56,12 @@ def symbols_find(arg):
             tokNum, tokVal = tok
             if tokNum == NAME:
                 name = tokVal
+
+                # Hack to fix common naming problem.  Perhaps use a dictionary
+                # of symbol aliases?
+                if name == 'omega0':
+                    name = 'omega_0'
+                
                 if name not in local_dict and name not in global_dict:
                     symbols.append(name)
         return ([(NUMBER, '0')])
@@ -71,9 +77,15 @@ def symbols_find(arg):
     return [symbol_name(symbol) for symbol in arg.atoms(Symbol, AppliedUndef)]
 
 
-def parse(string, symbols={}, evaluate=True, local_dict={}, **assumptions):
+def parse(string, symbols=None, evaluate=True, local_dict=None, **assumptions):
     """Handle arbitrary strings that may refer to multiple symbols."""
 
+    if symbols is None:
+        symbols = {}
+    
+    if local_dict is None:
+        local_dict = {}
+    
     cache = assumptions.pop('cache', True)
 
     def auto_symbol(tokens, local_dict, global_dict):
@@ -95,6 +107,11 @@ def parse(string, symbols={}, evaluate=True, local_dict={}, **assumptions):
                                    (OP, '('), (NAME, repr(name)), (OP, ')')])
                     continue
 
+                # Hack to fix common naming problem.  Perhaps use a dictionary
+                # of symbol aliases?
+                if name == 'omega0':
+                    name = 'omega_0'
+                
                 if name in global_dict:
 
                     obj = global_dict[name]
@@ -145,7 +162,7 @@ def parse(string, symbols={}, evaluate=True, local_dict={}, **assumptions):
     return s
 
 
-def sympify1(arg, symbols={}, evaluate=True, **assumptions):
+def sympify1(arg, symbols=None, evaluate=True, **assumptions):
     """Create a SymPy expression.
 
     The purpose of this function is to head SymPy off at the pass and
@@ -153,6 +170,9 @@ def sympify1(arg, symbols={}, evaluate=True, **assumptions):
 
     """
 
+    if symbols is None:
+        symbols = {}
+
     if isinstance(arg, (Symbol, Expr)):
         return arg
 
