@@ -134,14 +134,27 @@ class tExpr(Expr):
         return self.evaluate(t)
 
     def initial_value(self):
-        """Determine value at t = 0."""
+        """Determine value at t = 0. 
+        See also pre_initial_value and post_initial_value"""
 
         return self.subs(0)
 
+    def pre_initial_value(self):
+        """Determine value at t = 0-.
+        See also initial_value and post_initial_value"""
+
+        return self.limit(self.var, 0, dir='-')
+
+    def post_initial_value(self):
+        """Determine value at t = 0+.
+        See also pre_initial_value and initial_value"""
+
+        return self.limit(self.var, 0, dir='+')    
+
     def final_value(self):
         """Determine value at t = oo."""
 
-        return self.__class__(limit(self.expr, self.var, oo))
+        return self.limit(self.var, oo)
 
     def remove_condition(self):
         """Remove the piecewise condition from the expression.
@@ -259,12 +272,12 @@ class Ht(tExpr):
         self._laplace_conjugate_class = Hs
         self._fourier_conjugate_class = Hf
 
-def texpr(arg):
+def texpr(arg, **assumptions):
     """Create tExpr object.  If `arg` is tsym return t"""
 
     if arg is tsym:
         return t
-    return tExpr(arg)
+    return tExpr(arg, **assumptions)
 
 from .sexpr import Hs, Is, Vs, Ys, Zs, sExpr
 from .fexpr import Hf, If, Vf, Yf, Zf, fExpr
